use bcup::{models::ServerConfiguration, services::BackupServerService};
use futures::StreamExt;
use surrealdb::{engine::remote::ws::Ws, Notification, Result, Surreal};
use tracing::{debug, info, Level};

#[tokio::main]
async fn main() -> surrealdb::Result<()> {
    tracing_subscriber::fmt()
        .with_max_level(Level::DEBUG)
        .init();

    let db = Surreal::new::<Ws>("127.0.0.1:8000").await?;
    db.use_ns("test").use_db("test").await?;

    info!("Connected to db");

    let service = BackupServerService::new(db.clone());

    info!("Listening on table `rest_server` for changes");
    let mut stream = db.select("rest_server").live().await?;
    while let Some(result) = stream.next().await {
        handle(result, &service).await;
    }

    Ok(())
}
async fn handle(result: Result<Notification<ServerConfiguration>>, service: &BackupServerService) {
    debug!("Handeling incoming changes");
    match result {
        Ok(notification) => {
            let conf = &notification.data;
            if conf.state.is_pending() {
                process_new_item(conf, service).await;
            }
        }
        Err(error) => eprintln!("{error}"),
    }
}

async fn process_new_item(conf: &ServerConfiguration, service: &BackupServerService) {
    debug!("Processing the following item id:`{:?}`", &conf.id);

    service.spawn_restic_container(conf.directory.clone()).await;
    service
        .add_proxy_configuration(conf.directory.clone())
        .await;
    service.mark_data_as_processed(conf).await;
}
